﻿
local MAJOR, MINOR = "LibMounts-1.0", tonumber("20101011225649") or 99999999999999 -- dev version should ovewrite normal version
local lib = LibStub:NewLibrary(MAJOR, MINOR)

if not lib then return end

lib.data = LibStub("LibMounts-1.0_Data")

--- Retrives Mount Information including type, speed and location restrictions
-- @param id Spell id of a Mount
-- @usage local ground, air, water, speed, location = LibStub("LibMounts-1.0"):GetMountInfo(id)
-- @return **ground** <<color 00f>>boolean<</color>> true if mount is primarily a ground mount (or can switch between ground and air only modes)
-- @return **air** <<color 00f>>boolean<</color>> true if mount is primarily an air mount (or can switch between air and ground only modes)
-- @return **water** <<color 00f>>boolean<</color>> true if mount is primarily a water mount
-- @return **speed** <<color 00f>>number<</color>> speed of mount if non standard (will always be slower than standard)
-- @return **location** <<color 00f>>string<</color>> location this mount is restricted to (valid returns are "AQ" for the bug mounts and "Vashj'ir" for the Seahorse)
function lib:GetMountInfo(id)
	if lib.data["specialLocation"][id] then
		return unpack(lib.data["specialLocation"][id])
	else
		return lib.data["ground"][id], lib.data["air"][id], lib.data["water"][id], lib.data["specialSpeed"][id]
	end
end

lib.normalTypes = {
	["ground"] = true,
	["air"] = true,
	["water"] = true,
}
lib.specialTypes = {
	["AQ"] = true,
	["Vashj'ir"] = true,
}
--- Retrives a hash table of all mounts in the db of a certain type
-- @param MountType ground, air, water, AQ, Vashj'ir
-- @usage local mounts = LibStub("LibMounts-1.0"):GetMountList("AQ")
-- @return **mountTable** <<color 00f>>array<</color>> returns a hash table of mount ID's from the given mount type (mounts with special speeds are not returned)
function lib:GetMountList(MountType)
	local t = {}
	if lib.normalTypes[MountType] then
		for id in pairs(lib.data[MountType]) do
			if not lib.data.specialSpeed[id] then
				t[id] = true
			end
		end
	elseif lib.specialTypes[MountType] then
		for id, pack in pairs(lib.data.specialLocation) do
			if pack[5] == MountType then
				t[id] = true
			end
		end
	end
	return t
end